@@ -1,7 +1,7 @@
 from django import forms
 from django.utils.translation import gettext as _
-
-from front_door.conf import LOG_NONE, LOG_FAIL, LOG_PASS, LOG_RULE_FAIL, LOG_RULE_PASS, LOG_ALL
+from front_door.conf import (LOG_ALL, LOG_FAIL, LOG_NONE, LOG_PASS,
+                             LOG_RULE_FAIL, LOG_RULE_PASS)
 
 
 class FrontDoorLogLevel(forms.ChoiceField):
