@@ -1,6 +1,6 @@
 import logging.config
-from django.shortcuts import render
 
+from django.shortcuts import render
 from front_door.conf import config
 
 logger = logging.getLogger(__name__)
@@ -11,6 +11,7 @@ def front_door_panel(admin_site: "smart_admin.SmartAdminSite", request, extra_co
     context["title"] = "FrontDoor Configuration"
     context["config"] = config
 
-    return render(request, "frontdoor_panel.html", context)
+    return render(request, "frontdoor/smart_panel.html", context)
+
 
 front_door_panel.verbose_name = "FrontDoor Configuration"
