@@ -1,8 +1,8 @@
 import logging
 
+from .checker import front_door_check_access
 from .conf import config
 from .router import router
-from .rules import front_door_check_access
 from .utils import get_client_ip
 
 logger = logging.getLogger(__name__)
@@ -21,6 +21,8 @@ class FrontDoorMiddleware:
         request.user_ip = ip
         if front_door_check_access(request):
             response = self.get_response(request)
+            logger.error("Access ALLOWED")
         else:
             response = router.route(request)
+            logger.error("Access DENIED")
         return response
